Event triggered when a problem is submitted for solving.
Summary
Types
@type t() :: %Mojentic.Agents.SimpleRecursiveAgent.GoalSubmittedEvent{ state: Mojentic.Agents.SimpleRecursiveAgent.GoalState.t() }
Event triggered when a problem is submitted for solving.
@type t() :: %Mojentic.Agents.SimpleRecursiveAgent.GoalSubmittedEvent{ state: Mojentic.Agents.SimpleRecursiveAgent.GoalState.t() }