Mojentic.Examples.React.Events.FailureOccurred (Mojentic v1.2.0)

Copy Markdown View Source

Event to signal a failure in the ReAct loop.

This event captures errors or unrecoverable situations that prevent the agent from continuing to process the user's query.

Summary

Types

t()

@type t() :: %Mojentic.Examples.React.Events.FailureOccurred{
  context: Mojentic.Examples.React.Models.CurrentContext.t(),
  correlation_id: String.t() | nil,
  reason: String.t(),
  source: module()
}