Mojentic.Examples.React.Events.InvokeThinking (Mojentic v1.2.0)

Copy Markdown View Source

Event to trigger the thinking/planning phase.

This event initiates the planning process where the agent creates or refines a plan for answering the user's query.

Summary

Types

t()

@type t() :: %Mojentic.Examples.React.Events.InvokeThinking{
  context: Mojentic.Examples.React.Models.CurrentContext.t(),
  correlation_id: String.t() | nil,
  source: module()
}