Mojentic.Examples.React.OutputAgent (Mojentic v1.2.0)

Copy Markdown View Source

Output agent for the ReAct pattern.

This simple agent logs all events for observability and debugging.

Summary

Functions

Receives and logs any event.

Functions

receive_event_async(broker, event)

Receives and logs any event.

This agent acts as an observer, logging event information without producing new events.

Parameters

  • _broker: LLM broker (unused by this agent)
  • event: Any event in the ReAct loop

Returns

  • {:ok, []} - Never produces new events