Mojentic.LLM.Tools.EphemeralTaskManager.AppendTask (Mojentic v1.2.0)

Copy Markdown View Source

Tool for appending a new task to the end of the ephemeral task manager list.

This module creates a wrapper that holds a reference to the shared task list agent.

Examples

{:ok, agent} = Agent.start_link(fn -> TaskList.new() end)
tool = Mojentic.LLM.Tools.EphemeralTaskManager.AppendTask.new(agent)
{:ok, result} = tool.run(%{"description" => "My task"})

Summary

Functions

Creates a new AppendTask tool with the given agent.

Functions

new(agent)

Creates a new AppendTask tool with the given agent.