Tool for completing a task in the ephemeral task manager.
This tool changes a task's status from :in_progress to :completed.
Summary
Functions
Creates a new CompleteTask tool with the given agent.
Tool for completing a task in the ephemeral task manager.
This tool changes a task's status from :in_progress to :completed.
Creates a new CompleteTask tool with the given agent.