Mojentic.LLM.Tools.EphemeralTaskManager.InsertTaskAfter (Mojentic v1.2.0)

Copy Markdown View Source

Tool for inserting a new task after an existing task in the ephemeral task manager list.

This tool wraps a TaskList agent process that manages the shared task state.

Summary

Functions

Creates a new InsertTaskAfter tool with the given agent.

Functions

new(agent)

Creates a new InsertTaskAfter tool with the given agent.