Mojentic.LLM.Tools.EphemeralTaskManager.PrependTask (Mojentic v1.2.0)

Copy Markdown View Source

Tool for prepending a new task to the beginning of the ephemeral task manager list.

This tool wraps a TaskList agent process that manages the shared task state.

Summary

Functions

Creates a new PrependTask tool with the given agent.

Functions

new(agent)

Creates a new PrependTask tool with the given agent.