Tool for starting a task in the ephemeral task manager.
This tool changes a task's status from :pending to :in_progress.
Summary
Functions
Creates a new StartTask tool with the given agent.
Tool for starting a task in the ephemeral task manager.
This tool changes a task's status from :pending to :in_progress.
Creates a new StartTask tool with the given agent.