Tool for listing all files recursively in a directory.
Summary
Types
@type t() :: %Mojentic.LLM.Tools.ListAllFilesTool{ fs: Mojentic.LLM.Tools.FilesystemGateway.t() }
Functions
@spec new(Mojentic.LLM.Tools.FilesystemGateway.t()) :: t()
Tool for listing all files recursively in a directory.
@type t() :: %Mojentic.LLM.Tools.ListAllFilesTool{ fs: Mojentic.LLM.Tools.FilesystemGateway.t() }
@spec new(Mojentic.LLM.Tools.FilesystemGateway.t()) :: t()