Event to signal a failure in the ReAct loop.
This event captures errors or unrecoverable situations that prevent the agent from continuing to process the user's query.
Summary
Types
@type t() :: %Mojentic.Examples.React.Events.FailureOccurred{ context: Mojentic.Examples.React.Models.CurrentContext.t(), correlation_id: String.t() | nil, reason: String.t(), source: module() }