Event to trigger the decision-making phase.
This event initiates the decision process where the agent evaluates the current plan and history to decide on the next action.
Summary
Types
@type t() :: %Mojentic.Examples.React.Events.InvokeDecisioning{ context: Mojentic.Examples.React.Models.CurrentContext.t(), correlation_id: String.t() | nil, source: module() }