Output agent for the ReAct pattern.
This simple agent logs all events for observability and debugging.
Summary
Functions
Receives and logs any event.
Output agent for the ReAct pattern.
This simple agent logs all events for observability and debugging.
Receives and logs any event.