Tool for prepending a new task to the beginning of the ephemeral task manager list.
This tool wraps a TaskList agent process that manages the shared task state.
Summary
Functions
Creates a new PrependTask tool with the given agent.
Tool for prepending a new task to the beginning of the ephemeral task manager list.
This tool wraps a TaskList agent process that manages the shared task state.
Creates a new PrependTask tool with the given agent.